@@ -47,6 +47,9 @@ FAILEDOPERATION_INQUIRYREFUNDPRICEFAILED = 'FailedOperation.InquiryRefundPriceFa
 # 请求不支持`EMR`的实例`ins-xxxxxxxx`。
 FAILEDOPERATION_INVALIDINSTANCEAPPLICATIONROLEEMR = 'FailedOperation.InvalidInstanceApplicationRoleEmr'
 
+# 子网可用IP已耗尽。
+FAILEDOPERATION_NOAVAILABLEIPADDRESSCOUNTINSUBNET = 'FailedOperation.NoAvailableIpAddressCountInSubnet'
+
 # 当前实例没有弹性IP
 FAILEDOPERATION_NOTFOUNDEIP = 'FailedOperation.NotFoundEIP'
 
@@ -89,6 +92,9 @@ IMAGEQUOTALIMITEXCEEDED = 'ImageQuotaLimitExceeded'
 # 表示当前创建的实例个数超过了该账户允许购买的剩余配额数。
 INSTANCESQUOTALIMITEXCEEDED = 'InstancesQuotaLimitExceeded'
 
+# 内部错误。
+INTERNALERROR = 'InternalError'
+
 # 内部错误
 INTERNALERROR_TRADEUNKNOWNERROR = 'InternalError.TradeUnknownError'
 
@@ -212,9 +218,15 @@ INVALIDPARAMETER_HOSTNAMEILLEGAL = 'InvalidParameter.HostNameIllegal'
 # 当前接口不支持实例镜像。
 INVALIDPARAMETER_INSTANCEIMAGENOTSUPPORT = 'InvalidParameter.InstanceImageNotSupport'
 
+# 云盘资源售罄。
+INVALIDPARAMETER_INVALIDCLOUDDISKSOLDOUT = 'InvalidParameter.InvalidCloudDiskSoldOut'
+
 # 参数依赖不正确。
 INVALIDPARAMETER_INVALIDDEPENDENCE = 'InvalidParameter.InvalidDependence'
 
+# 当前操作不支持该类型实例。
+INVALIDPARAMETER_INVALIDINSTANCENOTSUPPORTED = 'InvalidParameter.InvalidInstanceNotSupported'
+
 # 指定的私有网络ip格式不正确。
 INVALIDPARAMETER_INVALIDIPFORMAT = 'InvalidParameter.InvalidIpFormat'
 
@@ -233,6 +245,9 @@ INVALIDPARAMETER_LOCALDATADISKNOTSUPPORT = 'InvalidParameter.LocalDataDiskNotSup
 # 不支持同时指定密钥登陆和保持镜像登陆方式。
 INVALIDPARAMETER_PARAMETERCONFLICT = 'InvalidParameter.ParameterConflict'
 
+# 不支持设置登陆密码。
+INVALIDPARAMETER_PASSWORDNOTSUPPORTED = 'InvalidParameter.PasswordNotSupported'
+
 # 指定的快照不存在。
 INVALIDPARAMETER_SNAPSHOTNOTFOUND = 'InvalidParameter.SnapshotNotFound'
 
@@ -287,6 +302,9 @@ INVALIDPARAMETERVALUE_IPV6ADDRESSMALFORMED = 'InvalidParameterValue.IPv6AddressM
 # HostName参数值不合法
 INVALIDPARAMETERVALUE_ILLEGALHOSTNAME = 'InvalidParameterValue.IllegalHostName'
 
+# 不支持操作不同计费方式的实例。
+INVALIDPARAMETERVALUE_INSTANCENOTSUPPORTEDMIXPRICINGMODEL = 'InvalidParameterValue.InstanceNotSupportedMixPricingModel'
+
 # 指定机型不存在
 INVALIDPARAMETERVALUE_INSTANCETYPENOTFOUND = 'InvalidParameterValue.InstanceTypeNotFound'
 
@@ -323,9 +341,21 @@ INVALIDPARAMETERVALUE_INVALIDIMAGESTATE = 'InvalidParameterValue.InvalidImageSta
 # IP地址不符合规范
 INVALIDPARAMETERVALUE_INVALIDIPFORMAT = 'InvalidParameterValue.InvalidIpFormat'
 
+# 实例启动模板描述格式错误。
+INVALIDPARAMETERVALUE_INVALIDLAUNCHTEMPLATEDESCRIPTION = 'InvalidParameterValue.InvalidLaunchTemplateDescription'
+
+# 实例启动模板名称格式错误。
+INVALIDPARAMETERVALUE_INVALIDLAUNCHTEMPLATENAME = 'InvalidParameterValue.InvalidLaunchTemplateName'
+
+# 实例启动模板描述格式错误。
+INVALIDPARAMETERVALUE_INVALIDLAUNCHTEMPLATEVERSIONDESCRIPTION = 'InvalidParameterValue.InvalidLaunchTemplateVersionDescription'
+
 # 参数值错误。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'
 
+# 无效密码。指定的密码不符合密码复杂度限制。例如密码长度不符合限制等。
+INVALIDPARAMETERVALUE_INVALIDPASSWORD = 'InvalidParameterValue.InvalidPassword'
+
 # 时间格式不合法。
 INVALIDPARAMETERVALUE_INVALIDTIMEFORMAT = 'InvalidParameterValue.InvalidTimeFormat'
 
@@ -341,12 +371,30 @@ INVALIDPARAMETERVALUE_KEYPAIRNOTFOUND = 'InvalidParameterValue.KeyPairNotFound'
 # 指定的密钥不支持当前操作。
 INVALIDPARAMETERVALUE_KEYPAIRNOTSUPPORTED = 'InvalidParameterValue.KeyPairNotSupported'
 
+# 不支持删除默认启动模板版本。
+INVALIDPARAMETERVALUE_LAUNCHTEMPLATEDEFAULTVERSION = 'InvalidParameterValue.LaunchTemplateDefaultVersion'
+
+# 实例启动模板ID格式错误。
+INVALIDPARAMETERVALUE_LAUNCHTEMPLATEIDMALFORMED = 'InvalidParameterValue.LaunchTemplateIdMalformed'
+
 # 实例启动模板ID不存在。
 INVALIDPARAMETERVALUE_LAUNCHTEMPLATEIDNOTEXISTED = 'InvalidParameterValue.LaunchTemplateIdNotExisted'
 
+# 实例启动模板和版本ID组合不存在。
+INVALIDPARAMETERVALUE_LAUNCHTEMPLATEIDVERNOTEXISTED = 'InvalidParameterValue.LaunchTemplateIdVerNotExisted'
+
+# 实例启动模板未找到。
+INVALIDPARAMETERVALUE_LAUNCHTEMPLATENOTFOUND = 'InvalidParameterValue.LaunchTemplateNotFound'
+
+# 无效的实例启动模板版本号。
+INVALIDPARAMETERVALUE_LAUNCHTEMPLATEVERSION = 'InvalidParameterValue.LaunchTemplateVersion'
+
 # 参数值数量超过限制。
 INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'
 
+# 本地盘的限制范围。
+INVALIDPARAMETERVALUE_LOCALDISKSIZERANGE = 'InvalidParameterValue.LocalDiskSizeRange'
+
 # 参数值必须为开启DHCP的VPC
 INVALIDPARAMETERVALUE_MUSTDHCPENABLEDVPC = 'InvalidParameterValue.MustDhcpEnabledVpc'
 
@@ -380,6 +428,9 @@ INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'
 # VPC ID`xxx`不合要求，请提供规范的Vpc ID， 类似vpc-xxxxxxxx，字母x代表小写字符或者数字。
 INVALIDPARAMETERVALUE_VPCIDMALFORMED = 'InvalidParameterValue.VpcIdMalformed'
 
+# 指定的VpcId不存在。
+INVALIDPARAMETERVALUE_VPCIDNOTEXIST = 'InvalidParameterValue.VpcIdNotExist'
+
 # VPC网络与实例不在同一可用区
 INVALIDPARAMETERVALUE_VPCIDZONEIDNOTMATCH = 'InvalidParameterValue.VpcIdZoneIdNotMatch'
 
@@ -446,6 +497,12 @@ LIMITEXCEEDED_INSTANCEQUOTA = 'LimitExceeded.InstanceQuota'
 # 目标实例规格不支持当前规格的外网带宽上限，不支持调整。具体可参考[公网网络带宽上限](https://cloud.tencent.com/document/product/213/12523)。
 LIMITEXCEEDED_INSTANCETYPEBANDWIDTH = 'LimitExceeded.InstanceTypeBandwidth'
 
+# 实例启动模板数量超限。
+LIMITEXCEEDED_LAUNCHTEMPLATEQUOTA = 'LimitExceeded.LaunchTemplateQuota'
+
+# 实例启动模板版本数量超限。
+LIMITEXCEEDED_LAUNCHTEMPLATEVERSIONQUOTA = 'LimitExceeded.LaunchTemplateVersionQuota'
+
 # 预付费实例已购买数量已达到最大配额，请提升配额后重试。
 LIMITEXCEEDED_PREPAYQUOTA = 'LimitExceeded.PrepayQuota'
 
@@ -509,6 +566,9 @@ RESOURCEINSUFFICIENT_DISASTERRECOVERGROUPCVMQUOTA = 'ResourceInsufficient.Disast
 # 指定的实例类型库存不足。
 RESOURCEINSUFFICIENT_SPECIFIEDINSTANCETYPE = 'ResourceInsufficient.SpecifiedInstanceType'
 
+# 指定的实例类型在选择的可用区已售罄。
+RESOURCEINSUFFICIENT_ZONESOLDOUTFORSPECIFIEDINSTANCE = 'ResourceInsufficient.ZoneSoldOutForSpecifiedInstance'
+
 # 高性能计算集群不存在。
 RESOURCENOTFOUND_HPCCLUSTER = 'ResourceNotFound.HpcCluster'
 
@@ -557,6 +617,12 @@ UNAUTHORIZEDOPERATION_MFANOTFOUND = 'UnauthorizedOperation.MFANotFound'
 # 无权操作指定的资源，请正确配置CAM策略。
 UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied'
 
+# 未知参数错误。
+UNKNOWNPARAMETER = 'UnknownParameter'
+
+# 操作不支持。
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
 # 指定的实例付费模式或者网络付费模式不支持共享带宽包
 UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.BandwidthPackageIdNotSupported'
 
@@ -566,6 +632,9 @@ UNSUPPORTEDOPERATION_IPV6NOTSUPPORTVPCMIGRATE = 'UnsupportedOperation.IPv6NotSup
 # 请求不支持该实例计费模式
 UNSUPPORTEDOPERATION_INSTANCECHARGETYPE = 'UnsupportedOperation.InstanceChargeType'
 
+# 不支持混合付费模式。
+UNSUPPORTEDOPERATION_INSTANCEMIXEDPRICINGMODEL = 'UnsupportedOperation.InstanceMixedPricingModel'
+
 # 请求不支持操作系统为`Xserver windows2012cndatacenterx86_64`的实例`ins-xxxxxx` 。
 UNSUPPORTEDOPERATION_INSTANCEOSWINDOWS = 'UnsupportedOperation.InstanceOsWindows'
 
@@ -680,6 +749,9 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILYTOARM = 'UnsupportedOperatio
 # 目标机型是SA3, 不支持变配。
 UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILYTOSA3 = 'UnsupportedOperation.UnsupportedChangeInstanceFamilyToSA3'
 
+# 不支持实例变配到此类型机型。
+UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCETOTHISINSTANCEFAMILY = 'UnsupportedOperation.UnsupportedChangeInstanceToThisInstanceFamily'
+
 # 请求不支持国际版账号
 UNSUPPORTEDOPERATION_UNSUPPORTEDINTERNATIONALUSER = 'UnsupportedOperation.UnsupportedInternationalUser'
 
